@@ -542,7 +542,7 @@ make_kb_list(GtkWidget *dlg)
 			fname = (char *)g_dir_read_name(dir);
 			if (fname) {
 				fname = g_build_filename("/usr/share/scv_layouts", fname, NULL);
-				description = scv_file_read_description(fname);
+				description = scv_file_read_description(fname, NULL);
 
 				if (fname && description) {
 					is_empty = FALSE;
@@ -602,7 +602,8 @@ btn_open_dialog_response(GtkWidget *dlg, int response, GtkWidget *wnd)
 		gtk_widget_destroy(dlg);
 	}
 	else {
-		ScvFile *scv_file = scv_file_new_from_file(fname);
+		GError *error = NULL;
+		ScvFile *scv_file = scv_file_new_from_file(fname, &error);
 
 		if (scv_file) {
 			if (wnd)
@@ -612,11 +613,14 @@ btn_open_dialog_response(GtkWidget *dlg, int response, GtkWidget *wnd)
 			make_wnd(scv_file);
 		}
 		else {
-			GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(dlg), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failed to load file \"%s\"", fname);
+			GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(dlg), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failed to load file \"%s\": ",
+				fname, error ? error->message : "Unknown error");
 
 			gtk_dialog_run(GTK_DIALOG(msg_dialog));
 			gtk_widget_destroy(msg_dialog);
 		}
+		if (error)
+			g_error_free(error);
 	}
 }
 
@@ -638,8 +642,10 @@ try_to_save_file(GtkWidget *wnd, int response, ScvFile *scv_file_old)
 		gtk_widget_destroy(msg_dialog);
 
 		if (GTK_RESPONSE_YES == response) {
-			if (!scv_file_save(scv_file_old)) {
-				GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(wnd), 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "Failed to save the current keyboard layout. Open the new one anyway?");
+			GError *error = NULL;
+			if (!scv_file_save(scv_file_old, &error)) {
+				GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(wnd), 0, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "Failed to save the current keyboard layout: %s\nOpen the new one anyway?",
+					error ? error->message : "Unknown error");
 
 				gtk_dialog_add_buttons(GTK_DIALOG(msg_dialog),
 					GTK_STOCK_OPEN,   GTK_RESPONSE_YES,
@@ -653,6 +659,8 @@ try_to_save_file(GtkWidget *wnd, int response, ScvFile *scv_file_old)
 			}
 			else
 				g_object_set_data(G_OBJECT(wnd), IS_DIRTY_KEY, GINT_TO_POINTER(FALSE));
+			if (error)
+				g_error_free(error);
 		}
 	}
 
@@ -695,13 +703,20 @@ static void
 btn_save_clicked(GtkWidget *btn, GtkWidget *wnd)
 {
 	ScvFile *scv_file_old = g_object_get_data(G_OBJECT(wnd), SCV_FILE_KEY);
-	if (!scv_file_save(scv_file_old)) {
-		GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(wnd), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failed to save the current keyboard layout.");
+	GError *error = NULL;
 
+	if (!scv_file_save(scv_file_old, &error)) {
+		GtkWidget *msg_dialog = gtk_message_dialog_new(GTK_WINDOW(wnd), 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failed to save the current keyboard layout: %s",
+			error ? error->message : "Unknown error");
+
+		gtk_dialog_run(GTK_DIALOG(msg_dialog));
 		gtk_widget_destroy(msg_dialog);
 	}
 	else
 		g_object_set_data(G_OBJECT(wnd), IS_DIRTY_KEY, GINT_TO_POINTER(FALSE));
+
+	if (error)
+		g_error_free(error);
 }
 
 static void
@@ -796,8 +811,20 @@ main(int argc, char **argv)
 
 	gtk_init(&argc, &argv);
 
-	if (argc == 2)
-		scv_file = scv_file_new_from_file(argv[1]);
+	if (argc == 2) {
+		GError *error = NULL;
+		scv_file = scv_file_new_from_file(argv[1], &error);
+
+		if (!scv_file) {
+			GtkWidget *msg_dialog = gtk_message_dialog_new(NULL, 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "Failed to load file \"%s\": ",
+				argv[1], error ? error->message : "Unknown error");
+
+			gtk_dialog_run(GTK_DIALOG(msg_dialog));
+			gtk_widget_destroy(msg_dialog);
+		}
+		if (error)
+			g_error_free(error);
+	}
 
 	make_wnd(scv_file);
 
